#
# spec file for package five-or-more
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           five-or-more
Version:        3.32.3
Release:        bp155.1.8
Summary:        "Five or More" Game for GNOME
License:        GPL-2.0-or-later
Group:          Amusements/Games/Board/Puzzle
URL:            https://wiki.gnome.org/Apps/Five_or_more
Source0:        https://download.gnome.org/sources/five-or-more/3.32/%{name}-%{version}.tar.xz

BuildRequires:  fdupes
BuildRequires:  itstool
BuildRequires:  libxml2-tools
BuildRequires:  meson >= 0.43
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(gio-2.0) >= 2.32
BuildRequires:  pkgconfig(glib-2.0) >= 2.32
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.20.0
BuildRequires:  pkgconfig(libgnome-games-support-1)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0
Recommends:     %{name}-doc

%description
Five or More is a game where one must align colored pieces as the
board gets filled with randomly placed pieces. When five or more
pieces of the same color get lined up, they disappear. The game ends
when the board gets filled up all the way.

This package provides the binary, manual and data files for Five or More.

%package doc
Summary:        Documentation for the "Five or More" GNOME game
Group:          Documentation/Other
BuildArch:      noarch

%description doc
Five or More is a game where one must align colored pieces as the
board gets filled with randomly placed pieces. When five or more
pieces of the same color get lined up, they disappear. The game ends
when the board gets filled up all the way.

This package contains the help documentation for Five or More.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}/%{_datadir}

%files
%license COPYING
%doc NEWS
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.gnome.five-or-more.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.five-or-more.gschema.xml
%{_datadir}/icons/hicolor/
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_datadir}/metainfo/org.gnome.five-or-more.appdata.xml

%files doc
%doc %{_datadir}/help/C/%{name}/

%files lang -f %{name}.lang

%changelog
* Thu Mar 31 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 3.32.3:
  + Fixed email of one of the authors.
  + Fixed minor meson warning.
  + Updated translations.
- Drop upstream merged patches: fix-build-vala-055.patch and
  fix-ref-gtk-child-unowned.patch.
* Sat Feb 19 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add fix-build-vala-055.patch: Backport: Fix build with vala
  0.55.x.
- Add fix-ref-gtk-child-unowned.patch: Reference of [GtkChild]
  fields is handled by GtkBuilder, type must be unowned.
* Sat Mar 28 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Fixed theme switcher working.
* Thu Mar 12 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.1:
  + Fixed translations not working.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated docs.
  + Updated translations.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Added snap build.
  + Updated translations.
* Sun Feb 17 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Nightly builds.
  + Appdata updates.
  + Tests for appdata and desktop validation.
  + Updated translations.
- Drop five-or-more-fix-help-build.patch: Fixed upstream.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.2:
  + Minor interface changes.
  + Updated translations.
- Changes from version 3.31.1:
  + Complete rewrite as part of GSoC.
  + Added new ball theme.
  + Remove appmenu.
  + Resource files with reverse domain naming.
  + Updated translations.
- Replace pkgconfig(gmodule-2.0) with pkgconfig(gmodule-export-2.0)
  BuildRequires: Align with what meson checks for.
- Add vala, pkgconfig(gee-0.8) and pkgconfig(gio-2.0)
  BuildRequires: New dependencies.
- Add five-or-more-fix-help-build.patch: Fix build of help files.
* Sun Sep  9 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
- Changes from version 3.29.3:
  + Updated translations.
  + Migrate to gettext.
  + Migrate to meson.
  + Use libgnome-games-support for scores tracking.
- Drop intltool BuildRequires: No longer needed after upstream
  migration to Gettext.
- Build with meson:
  + Add meson as build requirement.
  + Use appropriate macros.
- Add pkgconfig(libgnome-games-support-1) as build requirement.
- No longer recommend lang package as it already supplements main
  package (same effect, it's redundant).
* Mon Mar 12 2018 luc14n0@linuxmail.org
- Update to version 3.28.0:
  + Updated translations.
* Fri Mar  9 2018 jengelh@inai.de
- Update summaries.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Make theme names translatable.
  + Updated translations.
* Wed Feb 28 2018 luc14n0@linuxmail.org
- Update to version 3.27.91:
  + Updated translations.
- Update Url tag to https://wiki.gnome.org/Apps/Five_or_more:
  the current Five or More's web page.
- Drop glib2_gsettings_schema_*, icon_theme_cache_*,
  desktop_database_* post/postun scriptlets and
  glib2_gsettings_schema_requires macro: their functionality has
  been moved to RPM file triggers.
- Drop update-desktop-files BuildRequires and its macro: they are
  no longer required anymore.
- Add fdupes BuildRequires and its macro for replacement of
  duplicates with links under the data directory.
- Split help documentation into a doc subpackage and add a
  Recommens tag for it: more than half the size of the package was
  documentation files.
- Update package description to show the content provided by the
  package.
- Remove pristine Obsoletes tag for glines.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Updated translations.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Updated required GTK version.
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 3.25.90:
  + Replaced deprecated set focus on click call.
  + Fix Bugzilla submit bug button text (bgo#767264).
  + Updated translations.
* Thu Nov 10 2016 firebird209@gmail.com
- Update to version 3.22.2:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Added content ratings.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Tue Aug 30 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + Fixed theme loading.
  + Updated translations.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.21.90:
  + Updated appdata.
  + Updated translations.
* Wed Aug 17 2016 zaitor@opensuse.org
- Update to version 3.20.2:
  + Fix theme loading.
  + Updated translations.
* Sun Jul 31 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Fix Quit menu item and keyboard shortcut.
  + Fix window size growing out of control with GTK+ 3.20.
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.92:
  + Updated translations.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 3.19.91:
  + Provide highres icon.
  + Updated the appdata to spec version 0.7+.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Stop using deprecated gnome-common.
  + Add pre-commit and pre-applypatch hooks.
  + Updated translations.
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 3.19.3:
  + Updated appdata and doap.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Fixes for theme change help page.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Fixed window dragging.
  + Updated translations.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Provide symbolic app icon.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 zaitor@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Remove New Game from appmenu.
  + Remove .gitignore from version Control.
  + Fix comparison of pointer with integer.
  + Updated translations.
* Mon Jan 26 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Confirm before restarting the game on board size change.
  + Mark new string for translation.
  + Use imperative verb for the new dialog's action.
  + Don't enter a score of zero in high scores.
  + Fixed various memory leaks.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Switch to appstream util validate from appdata validation.
  + Remove GNOME Games branding from about dialog.
  + Deprecation fixes.
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Updated translations.
* Wed Sep 17 2014 dimstar@opensuse.org
- Drop special permission handling, incl pwdutils Requires: this
  was required back when there was a system wide, shared highscore
  list.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Fix insensitive new game menu item.
  + Set a reasonable minimum size for the game.
  + Show the preferences dialog in front of the main window.
  + Fix some memory leaks.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 3.13.90.1:
  + Fix insensitive new game button.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + Use a header bar for the preferences dialog.
  + Use text button for new game button.
  + Always show the new game button.
  + Distribute high contrast icons. Moved from
    gnome-themes-standard.
  + Updated translations.
- Add pkgconfig(glib-2.0) BuildRequires: new verified dependency.
- Build HighContrast icon cache in post/postun.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Mon Apr 14 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 dimstar@opensuse.org
- Update to version 3.12.0:
  + Fix some bugs with the user help.
  + Updated translations.
* Mon Mar 17 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Updated translations.
* Mon Feb 17 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + The game view is no longer far too small when playing with a
    Large field (regression in 3.11.5).
  + The new game button now works.
  + The new game button now has a tooltip.
  + The desktop file has been renamed to gnome-chess.desktop.
  + Updated translations.
- Update %%suse_update_desktop_file macro following upstream
  changes.
* Mon Feb  3 2014 dimstar@opensuse.org
- Update to version 3.11.5:
  + The size radio button in Preferences now always indicates the
    correct size.
  + A new game button now appears in the window after the game has
    ended.
  + Scores are now stored in the home directory, instead of in
    /var/games.
  + The binary no longer needs to be setgid in order for scores to
    work.
  + The outdated Classic and Pulse themes have been removed.
  + The default window size has been increased.
  + Updated translations.
- Remove calls to handle score files in /var/games.
- Drop gnome-games-scripts BuildRequires: no longer required, as
  we no longer have score files in /var/games.
* Mon Jan 13 2014 dimstar@opensuse.org
- Update to version 3.11.4:
  + Fix location of items on the right side of the headerbar with
    latest GTK+.
  + Updated translations.
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Use a GtkHeaderBar.
  + Fix preview area disappearing when selecting another window.
  + Updated translations.
* Tue Nov 19 2013 dimstar@opensuse.org
- Update to version 3.11.2:
  + Updated translations.
* Sun Nov 17 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Appdata is now translatable.
  + Updated translations.
* Mon Nov 11 2013 dimstar@opensuse.org
- Update to version 3.10.2 (bnc#849913):
  + Updated translations.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Updated translations.
* Mon Sep 23 2013 idonmez@suse.com
- Create games user/group on demand (fate#314560)
  + Depend on pwdutils for that to work.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 dimstar@opensuse.org
- Update to version 3.9.92:
  + Add an appdata file for GNOME Software.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Fix a crash when starting the game.
  + Replace the menu bar with an application menu.
  + Fullscreen option has been removed.
  + Preferences dialog no longer considered a separate window by
    GNOME Shell.
  + Fix two broken links in user help.
  + Updated translations.
* Sun Jun  2 2013 zaitor@opensuse.org
- Update to version 3.8.2:
  + Fix a crash on start on ubuntu.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Mon Apr  8 2013 dimstar@opensuse.org
- Also obsolete glines-lang from the main package.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Desktop file renamed back to glines.desktop.
  + Themes moved in from gnome-games-extra-data.
  + Updated translations.
* Fri Mar  1 2013 dimstar@opensuse.org
- Spec-cleanup using format_spec_file service.
* Mon Feb 18 2013 dimstar@opensuse.org
- Initial package, version 3.7.90:
  + Split out of gnome-games bundle package.
